@@ -10,9 +10,9 @@ class FindingsList(object):
     def __init__(self, findings_list):
         self.findings_list = findings_list
     
-    def describe(self):
+    def describe(self, descrip_value=False):
         # Return a series object
-        descrip_ss = pd.Series([i.describe() for i in self.findings_list])
+        descrip_ss = pd.Series([i.describe(descrip_value=descrip_value) for i in self.findings_list])
         return descrip_ss
     
     def describe_short(self):
@@ -20,8 +20,12 @@ class FindingsList(object):
         return descrip_ss
 
     @plot.plotter
-    def illustrate(self, n_col=1):
+    def illustrate(self, n_col=1, descrip_value=False, descrip_title=False, descrip_legend=False):
         for i, findings in enumerate(self.findings_list):
             ax = plt.subplot(len(self.findings_list), n_col, i + 1)
             ax.set_title(findings.describe_short())
-            findings.illustrate(ax=ax)
+            findings.illustrate(ax=ax, descrip_value=descrip_value, descrip_title=descrip_title, descrip_legend=descrip_legend)
+    
+    def set_descrip(self, descrip):
+        for i in self.findings_list:
+            i.descrip = descrip
