@@ -1,23 +1,23 @@
 from .description import Description
 from .encoder import Encoder
-from .jsonencoder import JSON_Encoder
+from .jsonencoder import JSONEncoder
 from .multiencoder import MultiEncoder
 from .questionnaire import Questionnaire
 from .scoring import Scoring
 from .label import Label
 from .generate_json_encoding import generate_json_encoding
-from .interval_label import Interval_Label
-from .quartile_label import Quartile_Label
+from .interval_label import IntervalLabel
+from .quartile_label import QuartileLabel
 
 __all__ = [
     "Description",
     "Encoder",
-    "JSON_Encoder",
+    "JSONEncoder",
     "MultiEncoder",
     "Questionnaire",
     "Scoring",
     "Label",
     "generate_json_encoding",
-    "Interval_Label",
-    "Quartile_Label",
+    "IntervalLabel",
+    "QuartileLabel",
 ]
\ No newline at end of file
